pub struct FixResult {
pub xml: String,
pub applied: Vec<AppliedFix>,
pub remaining: Vec<Issue>,
}Expand description
The result of a fix or fix_with_context call.
Fields
xml: StringThe repaired VAST XML. Always well-formed; may differ structurally from the input if the input contained XML comments or processing instructions (these are stripped — see module-level docs).
applied: Vec<AppliedFix>All fixes that were successfully applied, in document order.
remaining: Vec<Issue>Issues that remain after all fixes were applied. These require manual intervention.