pub struct ValidationResult {
pub version: DetectedVersion,
pub issues: Vec<Issue>,
pub summary: Summary,
}Expand description
The full result of validating a VAST document.
Contains the detected version, all issues found, and a summary with counts.
The issues vector is ordered by document position (depth-first traversal).
Fields
version: DetectedVersionissues: Vec<Issue>summary: SummaryTrait Implementations
Sourceimpl Clone for ValidationResult
impl Clone for ValidationResult
Sourcefn clone(&self) -> ValidationResult
fn clone(&self) -> ValidationResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ValidationResult
impl RefUnwindSafe for ValidationResult
impl Send for ValidationResult
impl Sync for ValidationResult
impl Unpin for ValidationResult
impl UnsafeUnpin for ValidationResult
impl UnwindSafe for ValidationResult